%define glib2_version           2.6.0
%define dbus_version            0.90
%define dbus_glib_version       0.70
%define polkit_version          0.92

Summary: System daemon for tracking users, sessions and seats
Name: ConsoleKit
Version: 0.4.1
Release: 3%{?dist}
License: GPLv2+
Group: System Environment/Libraries
URL: http://www.freedesktop.org/wiki/Software/ConsoleKit
Source0: http://www.freedesktop.org/software/ConsoleKit/dist/ConsoleKit-%{version}.tar.bz2
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Requires: dbus >= %{dbus_version}
Requires: dbus-glib >= %{dbus_glib_version}

BuildRequires: glib2-devel >= %{glib2_version}
BuildRequires: dbus-devel  >= %{dbus_version}
BuildRequires: dbus-glib-devel >= %{dbus_glib_version}
BuildRequires: polkit-devel >= %{polkit_version}
BuildRequires: pam-devel
BuildRequires: libX11-devel
BuildRequires: zlib-devel
BuildRequires: xmlto
BuildRequires: automake, autoconf, libtool

# https://bugs.freedesktop.org/show_bug.cgi?id=25656
Patch0: nodaemon.patch
# https://bugzilla.redhat.com/show_bug.cgi?id=547808
Patch1: reorder-initialization.patch

%description
ConsoleKit is a system daemon for tracking what users are logged
into the system and how they interact with the computer (e.g.
which keyboard and mouse they use).

It provides asynchronous notification via the system message bus.

%package x11
Summary: X11-requiring add-ons for ConsoleKit
License: GPLv2+
Group: Development/Libraries
Requires: %name = %{version}-%{release}
Requires: libX11

%description x11
ConsoleKit contains some tools that require Xlib to be installed,
those are in this separate package so server systems need not install
X. Applications (such as xorg-x11-xinit) and login managers (such as
gdm) that need to register their X sessions with ConsoleKit needs to
have a Requires: for this package.

%package libs
Summary: ConsoleKit libraries
License: MIT
Group: Development/Libraries
Requires: pam
Requires: dbus >= %{dbus_version}

%description libs
This package contains libraries and a PAM module for interacting
with ConsoleKit.

%package devel
Summary: Development files for ConsoleKit
License: MIT
Group: Development/Libraries
Requires: dbus-devel >= %{dbus_version}
Requires: pkgconfig

%description devel
This package contains headers and libraries needed for
developing software that is interacting with ConsoleKit.

%package docs
Summary: Developer documentation for ConsoleKit
Group: Development/Libraries
Requires: %name = %{version}-%{release}
#BuildArch: noarch

%description docs
This package contains developer documentation for ConsoleKit.

%prep
%setup -q
%patch0 -p1 -b .nodaemon
%patch1 -p1 -b .reorder-initialization

%build
%configure --with-pid-file=%{_localstatedir}/run/console-kit-daemon.pid --enable-pam-module --with-pam-module-dir=/%{_lib}/security --enable-docbook-docs --docdir=%{_datadir}/doc/%{name}-%{version}

make

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT

rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT/%{_lib}/security/*.a
rm -f $RPM_BUILD_ROOT/%{_lib}/security/*.la

# make sure we don't package a history log
rm -f $RPM_BUILD_ROOT/%{_var}/log/ConsoleKit/history

# The sample upstart files are good enough for us.
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/event.d
cp data/ck-log-system-{start,stop,restart} $RPM_BUILD_ROOT%{_sysconfdir}/event.d

cp README AUTHORS NEWS COPYING $RPM_BUILD_ROOT%{_datadir}/doc/%{name}-%{version}

%clean
rm -rf $RPM_BUILD_ROOT

%post
if [ -f /var/log/ConsoleKit/history ]; then
   chmod a+r /var/log/ConsoleKit/history
fi

%files
%defattr(-,root,root,-)
%doc %dir %{_datadir}/doc/%{name}-%{version}
%doc %{_datadir}/doc/%{name}-%{version}/README
%doc %{_datadir}/doc/%{name}-%{version}/AUTHORS
%doc %{_datadir}/doc/%{name}-%{version}/NEWS
%doc %{_datadir}/doc/%{name}-%{version}/COPYING
%{_sysconfdir}/dbus-1/system.d/*
%config(noreplace) %{_sysconfdir}/event.d/*
%{_datadir}/dbus-1/system-services/*.service
%{_datadir}/polkit-1/actions/*.policy
%dir %{_sysconfdir}/ConsoleKit
%dir %{_sysconfdir}/ConsoleKit/seats.d
%dir %{_sysconfdir}/ConsoleKit/run-seat.d
%dir %{_sysconfdir}/ConsoleKit/run-session.d
%dir %{_prefix}/lib/ConsoleKit
%dir %{_prefix}/lib/ConsoleKit/scripts
%dir %{_prefix}/lib/ConsoleKit/run-seat.d
%dir %{_prefix}/lib/ConsoleKit/run-session.d
%dir %{_var}/run/ConsoleKit
%attr(755,root,root) %dir %{_var}/log/ConsoleKit
%config %{_sysconfdir}/ConsoleKit/seats.d/00-primary.seat
%{_sbindir}/console-kit-daemon
%{_sbindir}/ck-log-system-restart
%{_sbindir}/ck-log-system-start
%{_sbindir}/ck-log-system-stop
%{_bindir}/ck-history
%{_bindir}/ck-launch-session
%{_bindir}/ck-list-sessions
%{_prefix}/lib/ConsoleKit/scripts/*

%files x11
%defattr(-,root,root,-)
%{_libexecdir}/*

%files libs
%defattr(-,root,root,-)
%{_libdir}/lib*.so.*
/%{_lib}/security/*.so
%{_mandir}/man8/pam_ck_connector.8.gz

%files devel
%defattr(-,root,root,-)

%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*
%{_includedir}/*
%{_datadir}/dbus-1/interfaces/org.freedesktop.ConsoleKit.*.xml

%files docs
%defattr(-,root,root,-)
%doc %dir %{_datadir}/doc/%{name}-%{version}/spec
%doc %{_datadir}/doc/%{name}-%{version}/spec/*


%changelog

